.. _special-functions:


Functions
=========

Built-in Functions
==================

.. toctree::
   :maxdepth: 1

   sage/functions/log
   sage/functions/trig
   sage/functions/hyperbolic
   sage/functions/transcendental
   sage/functions/error
   sage/functions/piecewise
   sage/functions/spike_function
   sage/functions/orthogonal_polys
   sage/functions/other
   sage/functions/special
   sage/functions/hypergeometric
   sage/functions/jacobi
   sage/functions/airy
   sage/functions/bessel
   sage/functions/exp_integral
   sage/functions/wigner
   sage/functions/generalized
   sage/functions/prime_pi
   sage/functions/min_max

Please find extensive developer documentation for creating new functions
in :ref:`symbolic-calculus`, in particular in the section
:ref:`Classes for symbolic functions <symbolic-function-classes>`.

.. include:: ../footer.txt
